#ifndef NT2_INCLUDE_FUNCTIONS_DIVCEIL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIVCEIL_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/divceil.hpp>

#endif
